==> jc-1.4.0.tar.gz: polyglot/types/reflect/Attribute.h <==
// abstract class polyglot.types.reflect.Attribute

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d931fb91b452174 polyglot_types_reflect_Attribute

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_types_reflect_Attribute_H_
#define _JC_polyglot_types_reflect_Attribute_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_polyglot_types_reflect_Attribute$sub_refs	_jc_polyglot_types_reflect_Attribute$sub_refs;
typedef struct _jc_polyglot_types_reflect_Attribute$sub_nonrefs	_jc_polyglot_types_reflect_Attribute$sub_nonrefs;
typedef struct _jc_polyglot_types_reflect_Attribute$refs	_jc_polyglot_types_reflect_Attribute$refs;
typedef struct _jc_polyglot_types_reflect_Attribute$nonrefs	_jc_polyglot_types_reflect_Attribute$nonrefs;
typedef struct _jc_polyglot_types_reflect_Attribute$object	_jc_polyglot_types_reflect_Attribute$object;

typedef const struct _jc_polyglot_types_reflect_Attribute$vmethods	_jc_polyglot_types_reflect_Attribute$vmethods;
typedef const struct _jc_polyglot_types_reflect_Attribute$vtable	_jc_polyglot_types_reflect_Attribute$vtable;
typedef const struct _jc_polyglot_types_reflect_Attribute$vtype	_jc_polyglot_types_reflect_Attribute$vtype;

// Constructors
extern void _jc_polyglot_types_reflect_Attribute$method$_init$02b806c1c13eed5e(_jc_env *, struct _jc_polyglot_types_reflect_Attribute$object *, jint, jint);

// Virtual methods structure
struct _jc_polyglot_types_reflect_Attribute$vmethods {
};

// Vtable
struct _jc_polyglot_types_reflect_Attribute$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_types_reflect_Attribute$vmethods	polyglot_types_reflect_Attribute;
};

// Vtype
struct _jc_polyglot_types_reflect_Attribute$vtype {
	_jc_type			type;
	_jc_polyglot_types_reflect_Attribute$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_types_reflect_Attribute$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_types_reflect_Attribute$refs {
    _jc_polyglot_types_reflect_Attribute$sub_refs	polyglot_types_reflect_Attribute;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_types_reflect_Attribute$sub_nonrefs {
	jint	nameIndex;
	jint	length;
};

// Non-reference instance fields (object)
struct _jc_polyglot_types_reflect_Attribute$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_types_reflect_Attribute$sub_nonrefs	polyglot_types_reflect_Attribute;
};

// Object instance structure
struct _jc_polyglot_types_reflect_Attribute$object {
	_jc_polyglot_types_reflect_Attribute$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_types_reflect_Attribute$vtype	*vtype;
	_jc_polyglot_types_reflect_Attribute$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_types_reflect_Attribute$vtype _jc_polyglot_types_reflect_Attribute$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_types_reflect_Attribute, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_types_reflect_Attribute$class_object;

#endif	/* _JC_polyglot_types_reflect_Attribute_H_ */

==> jc-1.4.6.tar.gz: polyglot/types/reflect/Attribute.h <==
// abstract class polyglot.types.reflect.Attribute

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d931fb91b452174 polyglot_types_reflect_Attribute

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_types_reflect_Attribute_H_
#define _JC_polyglot_types_reflect_Attribute_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_polyglot_types_reflect_Attribute$sub_refs	_jc_polyglot_types_reflect_Attribute$sub_refs;
typedef struct _jc_polyglot_types_reflect_Attribute$sub_nonrefs	_jc_polyglot_types_reflect_Attribute$sub_nonrefs;
typedef struct _jc_polyglot_types_reflect_Attribute$refs	_jc_polyglot_types_reflect_Attribute$refs;
typedef struct _jc_polyglot_types_reflect_Attribute$nonrefs	_jc_polyglot_types_reflect_Attribute$nonrefs;
typedef struct _jc_polyglot_types_reflect_Attribute$object	_jc_polyglot_types_reflect_Attribute$object;

typedef const struct _jc_polyglot_types_reflect_Attribute$vmethods	_jc_polyglot_types_reflect_Attribute$vmethods;
typedef const struct _jc_polyglot_types_reflect_Attribute$vtable	_jc_polyglot_types_reflect_Attribute$vtable;
typedef const struct _jc_polyglot_types_reflect_Attribute$vtype	_jc_polyglot_types_reflect_Attribute$vtype;

// Constructors
extern void _jc_polyglot_types_reflect_Attribute$method$_init$02b806c1c13eed5e(_jc_env *, struct _jc_polyglot_types_reflect_Attribute$object *, jint, jint) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_polyglot_types_reflect_Attribute$vmethods {
};

// Vtable
struct _jc_polyglot_types_reflect_Attribute$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_types_reflect_Attribute$vmethods	polyglot_types_reflect_Attribute;
};

// Vtype
struct _jc_polyglot_types_reflect_Attribute$vtype {
	_jc_type			type;
	_jc_polyglot_types_reflect_Attribute$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_types_reflect_Attribute$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_types_reflect_Attribute$refs {
    _jc_polyglot_types_reflect_Attribute$sub_refs	polyglot_types_reflect_Attribute;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_types_reflect_Attribute$sub_nonrefs {
	jint	nameIndex;
	jint	length;
};

// Non-reference instance fields (object)
struct _jc_polyglot_types_reflect_Attribute$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_types_reflect_Attribute$sub_nonrefs	polyglot_types_reflect_Attribute;
};

// Object instance structure
struct _jc_polyglot_types_reflect_Attribute$object {
	_jc_polyglot_types_reflect_Attribute$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_types_reflect_Attribute$vtype	*vtype;
	_jc_polyglot_types_reflect_Attribute$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_types_reflect_Attribute$vtype _jc_polyglot_types_reflect_Attribute$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_types_reflect_Attribute, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_types_reflect_Attribute$class_object;

#endif	/* _JC_polyglot_types_reflect_Attribute_H_ */
